from ..broker import Broker


class IpRoutedNeighborBroker(Broker):
    controller = "ip_routed_neighbors"

    def show(self, **kwargs):
        """Shows the details for the specified ip routed neighbor.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param IPRoutedNeighborID: The internal NetMRI identifier for this neighbor/route relationship.
             :type IPRoutedNeighborID: Integer

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return ip_routed_neighbor: The ip routed neighbor identified by the specified IPRoutedNeighborID.
             :rtype ip_routed_neighbor: IpRoutedNeighbor

            """

        return self.api_request(self._get_method_fullname("show"), kwargs)

    def index(self, **kwargs):
        """Lists the available ip routed neighbors. Any of the inputs listed may be be used to narrow the list; other inputs will be ignored. Of the various ways to query lists, using this method is most efficient.

            **Inputs**

            |  ``api version min:`` 2.3
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceRouteID: The internal NetMRI identifier for the route which this record references.
             :type DeviceRouteID: Integer

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceRouteID: The internal NetMRI identifier for the route which this record references.
             :type DeviceRouteID: Array of Integer

            |  ``api version min:`` 2.3
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param IPRoutedNeighborID: The internal NetMRI identifier for this neighbor/route relationship.
             :type IPRoutedNeighborID: Integer

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param IPRoutedNeighborID: The internal NetMRI identifier for this neighbor/route relationship.
             :type IPRoutedNeighborID: Array of Integer

            |  ``api version min:`` 2.3
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param IPRoutedNeighborTimestamp: The date and time this record was collected or calculated.
             :type IPRoutedNeighborTimestamp: DateTime

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param IPRoutedNeighborTimestamp: The date and time this record was collected or calculated.
             :type IPRoutedNeighborTimestamp: Array of DateTime

            |  ``api version min:`` 2.3
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param NeighborID: The internal NetMRI identifier of the corresponding neighbor record for this relationship.
             :type NeighborID: Integer

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param NeighborID: The internal NetMRI identifier of the corresponding neighbor record for this relationship.
             :type NeighborID: Array of Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceGroupID: The internal NetMRI identifier of the device groups to which to limit the results.
             :type DeviceGroupID: Array of Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param timestamp: The data returned will represent the ip routed neighbors as of this date and time. If omitted, the result will indicate the most recently collected data.
             :type timestamp: DateTime

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param start: The record number to return in the selected page of data. It will always appear, although it may not be the first record. See the :limit for more information.
             :type start: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 1000

             :param limit: The size of the page of data, that is, the maximum number of records returned. The limit size will be used to break the data up into pages and the first page with the start record will be returned. So if you have 100 records and use a :limit of 10 and a :start of 10, you will get records 10-19. The maximum limit is 10000.
             :type limit: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` IPRoutedNeighborID

             :param sort: The data field(s) to use for sorting the output. Default is IPRoutedNeighborID. Valid values are IPRoutedNeighborID, DataSourceID, NeighborID, IPRoutedNeighborStartTime, IPRoutedNeighborEndTime, IPRoutedNeighborChangedCols, IPRoutedNeighborTimestamp, IPRoutedNeighborMapSource, DeviceRouteID.
             :type sort: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` asc

             :param dir: The direction(s) in which to sort the data. Default is 'asc'. Valid values are 'asc' and 'desc'.
             :type dir: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param select: The list of attributes to return for each IpRoutedNeighbor. Valid values are IPRoutedNeighborID, DataSourceID, NeighborID, IPRoutedNeighborStartTime, IPRoutedNeighborEndTime, IPRoutedNeighborChangedCols, IPRoutedNeighborTimestamp, IPRoutedNeighborMapSource, DeviceRouteID. If empty or omitted, all attributes will be returned.
             :type select: Array

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_field: The field name for NIOS GOTO that is used for locating a row position of records.
             :type goto_field: String

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_value: The value of goto_field for NIOS GOTO that is used for locating a row position of records.
             :type goto_value: String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return ip_routed_neighbors: An array of the IpRoutedNeighbor objects that match the specified input criteria.
             :rtype ip_routed_neighbors: Array of IpRoutedNeighbor

            """

        return self.api_list_request(self._get_method_fullname("index"), kwargs)

    def search(self, **kwargs):
        """Lists the available ip routed neighbors matching the input criteria. This method provides a more flexible search interface than the index method, but searching using this method is more demanding on the system and will not perform to the same level as the index method. The input fields listed below will be used as in the index method, to filter the result, along with the optional query string and XML filter described below.

            **Inputs**

            |  ``api version min:`` 2.3
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param DataSourceID: The internal NetMRI identifier for the collector NetMRI that collected this data record.
             :type DataSourceID: Integer

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DataSourceID: The internal NetMRI identifier for the collector NetMRI that collected this data record.
             :type DataSourceID: Array of Integer

            |  ``api version min:`` 2.3
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceRouteID: The internal NetMRI identifier for the route which this record references.
             :type DeviceRouteID: Integer

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceRouteID: The internal NetMRI identifier for the route which this record references.
             :type DeviceRouteID: Array of Integer

            |  ``api version min:`` 2.3
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param IPRoutedNeighborChangedCols: The fields that changed between this revision of the record and the previous revision.
             :type IPRoutedNeighborChangedCols: String

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param IPRoutedNeighborChangedCols: The fields that changed between this revision of the record and the previous revision.
             :type IPRoutedNeighborChangedCols: Array of String

            |  ``api version min:`` 2.3
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param IPRoutedNeighborEndTime: The ending effective time of this revision of this record, or empty if still in effect.
             :type IPRoutedNeighborEndTime: DateTime

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param IPRoutedNeighborEndTime: The ending effective time of this revision of this record, or empty if still in effect.
             :type IPRoutedNeighborEndTime: Array of DateTime

            |  ``api version min:`` 2.3
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param IPRoutedNeighborID: The internal NetMRI identifier for this neighbor/route relationship.
             :type IPRoutedNeighborID: Integer

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param IPRoutedNeighborID: The internal NetMRI identifier for this neighbor/route relationship.
             :type IPRoutedNeighborID: Array of Integer

            |  ``api version min:`` 2.3
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param IPRoutedNeighborMapSource: Internal tracking information for NetMRI algorithms.
             :type IPRoutedNeighborMapSource: String

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param IPRoutedNeighborMapSource: Internal tracking information for NetMRI algorithms.
             :type IPRoutedNeighborMapSource: Array of String

            |  ``api version min:`` 2.3
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param IPRoutedNeighborStartTime: The starting effective time of this revision of the record.
             :type IPRoutedNeighborStartTime: DateTime

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param IPRoutedNeighborStartTime: The starting effective time of this revision of the record.
             :type IPRoutedNeighborStartTime: Array of DateTime

            |  ``api version min:`` 2.3
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param IPRoutedNeighborTimestamp: The date and time this record was collected or calculated.
             :type IPRoutedNeighborTimestamp: DateTime

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param IPRoutedNeighborTimestamp: The date and time this record was collected or calculated.
             :type IPRoutedNeighborTimestamp: Array of DateTime

            |  ``api version min:`` 2.3
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param NeighborID: The internal NetMRI identifier of the corresponding neighbor record for this relationship.
             :type NeighborID: Integer

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param NeighborID: The internal NetMRI identifier of the corresponding neighbor record for this relationship.
             :type NeighborID: Array of Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceGroupID: The internal NetMRI identifier of the device groups to which to limit the results.
             :type DeviceGroupID: Array of Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param timestamp: The data returned will represent the ip routed neighbors as of this date and time. If omitted, the result will indicate the most recently collected data.
             :type timestamp: DateTime

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param start: The record number to return in the selected page of data. It will always appear, although it may not be the first record. See the :limit for more information.
             :type start: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 1000

             :param limit: The size of the page of data, that is, the maximum number of records returned. The limit size will be used to break the data up into pages and the first page with the start record will be returned. So if you have 100 records and use a :limit of 10 and a :start of 10, you will get records 10-19. The maximum limit is 10000.
             :type limit: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` IPRoutedNeighborID

             :param sort: The data field(s) to use for sorting the output. Default is IPRoutedNeighborID. Valid values are IPRoutedNeighborID, DataSourceID, NeighborID, IPRoutedNeighborStartTime, IPRoutedNeighborEndTime, IPRoutedNeighborChangedCols, IPRoutedNeighborTimestamp, IPRoutedNeighborMapSource, DeviceRouteID.
             :type sort: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` asc

             :param dir: The direction(s) in which to sort the data. Default is 'asc'. Valid values are 'asc' and 'desc'.
             :type dir: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param select: The list of attributes to return for each IpRoutedNeighbor. Valid values are IPRoutedNeighborID, DataSourceID, NeighborID, IPRoutedNeighborStartTime, IPRoutedNeighborEndTime, IPRoutedNeighborChangedCols, IPRoutedNeighborTimestamp, IPRoutedNeighborMapSource, DeviceRouteID. If empty or omitted, all attributes will be returned.
             :type select: Array

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_field: The field name for NIOS GOTO that is used for locating a row position of records.
             :type goto_field: String

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_value: The value of goto_field for NIOS GOTO that is used for locating a row position of records.
             :type goto_value: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param query: This value will be matched against ip routed neighbors, looking to see if one or more of the listed attributes contain the passed value. You may also surround the value with '/' and '/' to perform a regular expression search rather than a containment operation. Any record that matches will be returned. The attributes searched are: DataSourceID, DeviceRouteID, IPRoutedNeighborChangedCols, IPRoutedNeighborEndTime, IPRoutedNeighborID, IPRoutedNeighborMapSource, IPRoutedNeighborStartTime, IPRoutedNeighborTimestamp, NeighborID.
             :type query: String

            |  ``api version min:`` 2.3
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param xml_filter: A SetFilter XML structure to further refine the search. The SetFilter will be applied AFTER any search query or field values, but before any limit options. The limit and pagination will be enforced after the filter. Remind that this kind of filter may be costly and inefficient if not associated with a database filtering.
             :type xml_filter: String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return ip_routed_neighbors: An array of the IpRoutedNeighbor objects that match the specified input criteria.
             :rtype ip_routed_neighbors: Array of IpRoutedNeighbor

            """

        return self.api_list_request(self._get_method_fullname("search"), kwargs)

    def find(self, **kwargs):
        """Lists the available ip routed neighbors matching the input specification. This provides the most flexible search specification of all the query mechanisms, enabling searching using comparison operations other than equality. However, it is more complex to use and will not perform as efficiently as the index or search methods. In the input descriptions below, 'field names' refers to the following fields: DataSourceID, DeviceRouteID, IPRoutedNeighborChangedCols, IPRoutedNeighborEndTime, IPRoutedNeighborID, IPRoutedNeighborMapSource, IPRoutedNeighborStartTime, IPRoutedNeighborTimestamp, NeighborID.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_DataSourceID: The operator to apply to the field DataSourceID. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. DataSourceID: The internal NetMRI identifier for the collector NetMRI that collected this data record. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_DataSourceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_DataSourceID: If op_DataSourceID is specified, the field named in this input will be compared to the value in DataSourceID using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_DataSourceID must be specified if op_DataSourceID is specified.
             :type val_f_DataSourceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_DataSourceID: If op_DataSourceID is specified, this value will be compared to the value in DataSourceID using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_DataSourceID must be specified if op_DataSourceID is specified.
             :type val_c_DataSourceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_DeviceRouteID: The operator to apply to the field DeviceRouteID. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. DeviceRouteID: The internal NetMRI identifier for the route which this record references. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_DeviceRouteID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_DeviceRouteID: If op_DeviceRouteID is specified, the field named in this input will be compared to the value in DeviceRouteID using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_DeviceRouteID must be specified if op_DeviceRouteID is specified.
             :type val_f_DeviceRouteID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_DeviceRouteID: If op_DeviceRouteID is specified, this value will be compared to the value in DeviceRouteID using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_DeviceRouteID must be specified if op_DeviceRouteID is specified.
             :type val_c_DeviceRouteID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_IPRoutedNeighborChangedCols: The operator to apply to the field IPRoutedNeighborChangedCols. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. IPRoutedNeighborChangedCols: The fields that changed between this revision of the record and the previous revision. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_IPRoutedNeighborChangedCols: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_IPRoutedNeighborChangedCols: If op_IPRoutedNeighborChangedCols is specified, the field named in this input will be compared to the value in IPRoutedNeighborChangedCols using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_IPRoutedNeighborChangedCols must be specified if op_IPRoutedNeighborChangedCols is specified.
             :type val_f_IPRoutedNeighborChangedCols: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_IPRoutedNeighborChangedCols: If op_IPRoutedNeighborChangedCols is specified, this value will be compared to the value in IPRoutedNeighborChangedCols using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_IPRoutedNeighborChangedCols must be specified if op_IPRoutedNeighborChangedCols is specified.
             :type val_c_IPRoutedNeighborChangedCols: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_IPRoutedNeighborEndTime: The operator to apply to the field IPRoutedNeighborEndTime. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. IPRoutedNeighborEndTime: The ending effective time of this revision of this record, or empty if still in effect. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_IPRoutedNeighborEndTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_IPRoutedNeighborEndTime: If op_IPRoutedNeighborEndTime is specified, the field named in this input will be compared to the value in IPRoutedNeighborEndTime using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_IPRoutedNeighborEndTime must be specified if op_IPRoutedNeighborEndTime is specified.
             :type val_f_IPRoutedNeighborEndTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_IPRoutedNeighborEndTime: If op_IPRoutedNeighborEndTime is specified, this value will be compared to the value in IPRoutedNeighborEndTime using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_IPRoutedNeighborEndTime must be specified if op_IPRoutedNeighborEndTime is specified.
             :type val_c_IPRoutedNeighborEndTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_IPRoutedNeighborID: The operator to apply to the field IPRoutedNeighborID. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. IPRoutedNeighborID: The internal NetMRI identifier for this neighbor/route relationship. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_IPRoutedNeighborID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_IPRoutedNeighborID: If op_IPRoutedNeighborID is specified, the field named in this input will be compared to the value in IPRoutedNeighborID using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_IPRoutedNeighborID must be specified if op_IPRoutedNeighborID is specified.
             :type val_f_IPRoutedNeighborID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_IPRoutedNeighborID: If op_IPRoutedNeighborID is specified, this value will be compared to the value in IPRoutedNeighborID using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_IPRoutedNeighborID must be specified if op_IPRoutedNeighborID is specified.
             :type val_c_IPRoutedNeighborID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_IPRoutedNeighborMapSource: The operator to apply to the field IPRoutedNeighborMapSource. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. IPRoutedNeighborMapSource: Internal tracking information for NetMRI algorithms. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_IPRoutedNeighborMapSource: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_IPRoutedNeighborMapSource: If op_IPRoutedNeighborMapSource is specified, the field named in this input will be compared to the value in IPRoutedNeighborMapSource using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_IPRoutedNeighborMapSource must be specified if op_IPRoutedNeighborMapSource is specified.
             :type val_f_IPRoutedNeighborMapSource: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_IPRoutedNeighborMapSource: If op_IPRoutedNeighborMapSource is specified, this value will be compared to the value in IPRoutedNeighborMapSource using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_IPRoutedNeighborMapSource must be specified if op_IPRoutedNeighborMapSource is specified.
             :type val_c_IPRoutedNeighborMapSource: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_IPRoutedNeighborStartTime: The operator to apply to the field IPRoutedNeighborStartTime. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. IPRoutedNeighborStartTime: The starting effective time of this revision of the record. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_IPRoutedNeighborStartTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_IPRoutedNeighborStartTime: If op_IPRoutedNeighborStartTime is specified, the field named in this input will be compared to the value in IPRoutedNeighborStartTime using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_IPRoutedNeighborStartTime must be specified if op_IPRoutedNeighborStartTime is specified.
             :type val_f_IPRoutedNeighborStartTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_IPRoutedNeighborStartTime: If op_IPRoutedNeighborStartTime is specified, this value will be compared to the value in IPRoutedNeighborStartTime using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_IPRoutedNeighborStartTime must be specified if op_IPRoutedNeighborStartTime is specified.
             :type val_c_IPRoutedNeighborStartTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_IPRoutedNeighborTimestamp: The operator to apply to the field IPRoutedNeighborTimestamp. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. IPRoutedNeighborTimestamp: The date and time this record was collected or calculated. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_IPRoutedNeighborTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_IPRoutedNeighborTimestamp: If op_IPRoutedNeighborTimestamp is specified, the field named in this input will be compared to the value in IPRoutedNeighborTimestamp using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_IPRoutedNeighborTimestamp must be specified if op_IPRoutedNeighborTimestamp is specified.
             :type val_f_IPRoutedNeighborTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_IPRoutedNeighborTimestamp: If op_IPRoutedNeighborTimestamp is specified, this value will be compared to the value in IPRoutedNeighborTimestamp using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_IPRoutedNeighborTimestamp must be specified if op_IPRoutedNeighborTimestamp is specified.
             :type val_c_IPRoutedNeighborTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_NeighborID: The operator to apply to the field NeighborID. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. NeighborID: The internal NetMRI identifier of the corresponding neighbor record for this relationship. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_NeighborID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_NeighborID: If op_NeighborID is specified, the field named in this input will be compared to the value in NeighborID using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_NeighborID must be specified if op_NeighborID is specified.
             :type val_f_NeighborID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_NeighborID: If op_NeighborID is specified, this value will be compared to the value in NeighborID using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_NeighborID must be specified if op_NeighborID is specified.
             :type val_c_NeighborID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceGroupID: The internal NetMRI identifier of the device groups to which to limit the results.
             :type DeviceGroupID: Array of Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param timestamp: The data returned will represent the ip routed neighbors as of this date and time. If omitted, the result will indicate the most recently collected data.
             :type timestamp: DateTime

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param start: The record number to return in the selected page of data. It will always appear, although it may not be the first record. See the :limit for more information.
             :type start: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 1000

             :param limit: The size of the page of data, that is, the maximum number of records returned. The limit size will be used to break the data up into pages and the first page with the start record will be returned. So if you have 100 records and use a :limit of 10 and a :start of 10, you will get records 10-19. The maximum limit is 10000.
             :type limit: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` IPRoutedNeighborID

             :param sort: The data field(s) to use for sorting the output. Default is IPRoutedNeighborID. Valid values are IPRoutedNeighborID, DataSourceID, NeighborID, IPRoutedNeighborStartTime, IPRoutedNeighborEndTime, IPRoutedNeighborChangedCols, IPRoutedNeighborTimestamp, IPRoutedNeighborMapSource, DeviceRouteID.
             :type sort: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` asc

             :param dir: The direction(s) in which to sort the data. Default is 'asc'. Valid values are 'asc' and 'desc'.
             :type dir: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param select: The list of attributes to return for each IpRoutedNeighbor. Valid values are IPRoutedNeighborID, DataSourceID, NeighborID, IPRoutedNeighborStartTime, IPRoutedNeighborEndTime, IPRoutedNeighborChangedCols, IPRoutedNeighborTimestamp, IPRoutedNeighborMapSource, DeviceRouteID. If empty or omitted, all attributes will be returned.
             :type select: Array

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_field: The field name for NIOS GOTO that is used for locating a row position of records.
             :type goto_field: String

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_value: The value of goto_field for NIOS GOTO that is used for locating a row position of records.
             :type goto_value: String

            |  ``api version min:`` 2.3
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param xml_filter: A SetFilter XML structure to further refine the search. The SetFilter will be applied AFTER any search query or field values, but before any limit options. The limit and pagination will be enforced after the filter. Remind that this kind of filter may be costly and inefficient if not associated with a database filtering.
             :type xml_filter: String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return ip_routed_neighbors: An array of the IpRoutedNeighbor objects that match the specified input criteria.
             :rtype ip_routed_neighbors: Array of IpRoutedNeighbor

            """

        return self.api_list_request(self._get_method_fullname("find"), kwargs)



from ..remote import RemoteModel


class AuthServiceRemote(RemoteModel):
    """
    This table list out the entries of Authentication Services.


    |  ``id:`` The id of the authentication service.
    |  ``attribute type:`` number

    |  ``service_name:`` The name of the Authentication Service.
    |  ``attribute type:`` string

    |  ``auth_method:`` The Authentication method of the service. One of (local, radius, tacacs, ldap, activedirectory).
    |  ``attribute type:`` string

    |  ``description:`` Description/comment about this authentication service
    |  ``attribute type:`` string

    |  ``priority:`` The priority assigned to this Authentication Service.
    |  ``attribute type:`` number

    |  ``context_params_json:`` Additional specific authentication method parameters are stored in this field using a json format. (such as 'base_dn' for LDAP method, Vendor Specific Attribute ID for Radius,...).
    |  ``attribute type:`` string

    |  ``enabled_ind:`` A flag indicating whether the authentication service settings is enabled or disabled.
    |  ``attribute type:`` bool

    |  ``enabled_authz_ind:`` A flag indicating whether this service is used for computing privileges for the remote users.
    |  ``attribute type:`` bool

    |  ``timeout:`` The timeout interval of the service authentication servers.
    |  ``attribute type:`` number

    |  ``created_at:`` The date and time the record was initially created in NetMRI.
    |  ``attribute type:`` datetime

    |  ``updated_at:`` The date and time the record was last modified in NetMRI.
    |  ``attribute type:`` datetime

    """

    properties = ("id",
                  "service_name",
                  "auth_method",
                  "description",
                  "priority",
                  "context_params_json",
                  "enabled_ind",
                  "enabled_authz_ind",
                  "timeout",
                  "created_at",
                  "updated_at",
                  )



from ..remote import RemoteModel


class ApicSettingRemote(RemoteModel):
    """



    |  ``id:`` none
    |  ``attribute type:`` string

    |  ``virtual_network_id:`` none
    |  ``attribute type:`` string

    |  ``controller_address:`` none
    |  ``attribute type:`` string

    |  ``protocol:`` none
    |  ``attribute type:`` string

    |  ``sdn_username:`` none
    |  ``attribute type:`` string

    |  ``sdn_password:`` none
    |  ``attribute type:`` string

    |  ``SecureVersion:`` none
    |  ``attribute type:`` string

    |  ``created_at:`` none
    |  ``attribute type:`` string

    |  ``updated_at:`` none
    |  ``attribute type:`` string

    |  ``UnitID:`` none
    |  ``attribute type:`` string

    |  ``sdn_type:`` none
    |  ``attribute type:`` string

    |  ``api_key:`` none
    |  ``attribute type:`` string

    |  ``on_prem:`` none
    |  ``attribute type:`` string

    |  ``use_global_proxy:`` none
    |  ``attribute type:`` string

    |  ``handle:`` none
    |  ``attribute type:`` string

    |  ``scan_interface_id:`` none
    |  ``attribute type:`` string

    |  ``start_blackout_schedule:`` none
    |  ``attribute type:`` string

    |  ``blackout_duration:`` none
    |  ``attribute type:`` string

    |  ``max_requests_per_second:`` none
    |  ``attribute type:`` string

    |  ``collect_offline_devices:`` none
    |  ``attribute type:`` string

    |  ``ca_cert_id:`` none
    |  ``attribute type:`` string

    |  ``ca_cert_content:`` none
    |  ``attribute type:`` string

    """

    properties = ("id",
                  "virtual_network_id",
                  "controller_address",
                  "protocol",
                  "sdn_username",
                  "sdn_password",
                  "SecureVersion",
                  "created_at",
                  "updated_at",
                  "UnitID",
                  "sdn_type",
                  "api_key",
                  "on_prem",
                  "use_global_proxy",
                  "handle",
                  "scan_interface_id",
                  "start_blackout_schedule",
                  "blackout_duration",
                  "max_requests_per_second",
                  "collect_offline_devices",
                  "ca_cert_id",
                  "ca_cert_content",
                  )



from ..broker import Broker


class IfZoneBroker(Broker):
    controller = "if_zones"

    def show(self, **kwargs):
        """Shows the details for the specified if zone.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param IfZoneID: The internal NetMRI identifier for this relation between a Zone and an Interface of device.
             :type IfZoneID: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param methods: A list of if zone methods. The listed methods will be called on each if zone returned and included in the output. Available methods are: device_zone, data_source, device.
             :type methods: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param include: A list of associated object types to include in the output. The listed associations will be returned as outputs named according to the association name (see outputs below). Available includes are: device_zone, data_source, device.
             :type include: Array of String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return if_zone: The if zone identified by the specified IfZoneID.
             :rtype if_zone: IfZone

            """

        return self.api_request(self._get_method_fullname("show"), kwargs)

    def index(self, **kwargs):
        """Lists the available if zones. Any of the inputs listed may be be used to narrow the list; other inputs will be ignored. Of the various ways to query lists, using this method is most efficient.

            **Inputs**

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceID: The internal NetMRI identifier for the device for which belongs Zone and Interface.
             :type DeviceID: Array of Integer

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceZoneID: The internal NetMRI identifier of the Zone.
             :type DeviceZoneID: Array of Integer

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param IfZoneID: The internal NetMRI identifier for this relation between a Zone and an Interface of device.
             :type IfZoneID: Array of Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceGroupID: The internal NetMRI identifier of the device groups to which to limit the results.
             :type DeviceGroupID: Array of Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param timestamp: The data returned will represent the if zones as of this date and time. If omitted, the result will indicate the most recently collected data.
             :type timestamp: DateTime

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param methods: A list of if zone methods. The listed methods will be called on each if zone returned and included in the output. Available methods are: device_zone, data_source, device.
             :type methods: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param include: A list of associated object types to include in the output. The listed associations will be returned as outputs named according to the association name (see outputs below). Available includes are: device_zone, data_source, device.
             :type include: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param start: The record number to return in the selected page of data. It will always appear, although it may not be the first record. See the :limit for more information.
             :type start: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 1000

             :param limit: The size of the page of data, that is, the maximum number of records returned. The limit size will be used to break the data up into pages and the first page with the start record will be returned. So if you have 100 records and use a :limit of 10 and a :start of 10, you will get records 10-19. The maximum limit is 10000.
             :type limit: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` IfZoneID

             :param sort: The data field(s) to use for sorting the output. Default is IfZoneID. Valid values are IfZoneID, DeviceID, DataSourceID, DeviceZoneID, InterfaceID, ifZoneFirstSeenTime, ifZoneStartTime, ifZoneEndTime, ifZoneTimestamp, ifZoneChangedCols.
             :type sort: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` asc

             :param dir: The direction(s) in which to sort the data. Default is 'asc'. Valid values are 'asc' and 'desc'.
             :type dir: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param select: The list of attributes to return for each IfZone. Valid values are IfZoneID, DeviceID, DataSourceID, DeviceZoneID, InterfaceID, ifZoneFirstSeenTime, ifZoneStartTime, ifZoneEndTime, ifZoneTimestamp, ifZoneChangedCols. If empty or omitted, all attributes will be returned.
             :type select: Array

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_field: The field name for NIOS GOTO that is used for locating a row position of records.
             :type goto_field: String

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_value: The value of goto_field for NIOS GOTO that is used for locating a row position of records.
             :type goto_value: String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return if_zones: An array of the IfZone objects that match the specified input criteria.
             :rtype if_zones: Array of IfZone

            """

        return self.api_list_request(self._get_method_fullname("index"), kwargs)

    def search(self, **kwargs):
        """Lists the available if zones matching the input criteria. This method provides a more flexible search interface than the index method, but searching using this method is more demanding on the system and will not perform to the same level as the index method. The input fields listed below will be used as in the index method, to filter the result, along with the optional query string and XML filter described below.

            **Inputs**

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DataSourceID: The internal NetMRI identifier for the collector NetMRI that collected this data record.
             :type DataSourceID: Array of Integer

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceID: The internal NetMRI identifier for the device for which belongs Zone and Interface.
             :type DeviceID: Array of Integer

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceZoneID: The internal NetMRI identifier of the Zone.
             :type DeviceZoneID: Array of Integer

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param IfZoneID: The internal NetMRI identifier for this relation between a Zone and an Interface of device.
             :type IfZoneID: Array of Integer

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param InterfaceID: The internal NetMRI identifier of the Interface of the device.
             :type InterfaceID: Array of Integer

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param ifZoneChangedCols: The fields that changed between this revision of the record and the previous revision.
             :type ifZoneChangedCols: Array of String

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param ifZoneEndTime: The ending effective time of this record, or empty if still in effect.
             :type ifZoneEndTime: Array of DateTime

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param ifZoneFirstSeenTime: The timestamp of when NetMRI saw for the first time this relationship.
             :type ifZoneFirstSeenTime: Array of DateTime

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param ifZoneStartTime: The starting effective time of this record.
             :type ifZoneStartTime: Array of DateTime

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param ifZoneTimestamp: The date and time this record was collected or calculated.
             :type ifZoneTimestamp: Array of DateTime

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceGroupID: The internal NetMRI identifier of the device groups to which to limit the results.
             :type DeviceGroupID: Array of Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param timestamp: The data returned will represent the if zones as of this date and time. If omitted, the result will indicate the most recently collected data.
             :type timestamp: DateTime

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param methods: A list of if zone methods. The listed methods will be called on each if zone returned and included in the output. Available methods are: device_zone, data_source, device.
             :type methods: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param include: A list of associated object types to include in the output. The listed associations will be returned as outputs named according to the association name (see outputs below). Available includes are: device_zone, data_source, device.
             :type include: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param start: The record number to return in the selected page of data. It will always appear, although it may not be the first record. See the :limit for more information.
             :type start: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 1000

             :param limit: The size of the page of data, that is, the maximum number of records returned. The limit size will be used to break the data up into pages and the first page with the start record will be returned. So if you have 100 records and use a :limit of 10 and a :start of 10, you will get records 10-19. The maximum limit is 10000.
             :type limit: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` IfZoneID

             :param sort: The data field(s) to use for sorting the output. Default is IfZoneID. Valid values are IfZoneID, DeviceID, DataSourceID, DeviceZoneID, InterfaceID, ifZoneFirstSeenTime, ifZoneStartTime, ifZoneEndTime, ifZoneTimestamp, ifZoneChangedCols.
             :type sort: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` asc

             :param dir: The direction(s) in which to sort the data. Default is 'asc'. Valid values are 'asc' and 'desc'.
             :type dir: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param select: The list of attributes to return for each IfZone. Valid values are IfZoneID, DeviceID, DataSourceID, DeviceZoneID, InterfaceID, ifZoneFirstSeenTime, ifZoneStartTime, ifZoneEndTime, ifZoneTimestamp, ifZoneChangedCols. If empty or omitted, all attributes will be returned.
             :type select: Array

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_field: The field name for NIOS GOTO that is used for locating a row position of records.
             :type goto_field: String

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_value: The value of goto_field for NIOS GOTO that is used for locating a row position of records.
             :type goto_value: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param query: This value will be matched against if zones, looking to see if one or more of the listed attributes contain the passed value. You may also surround the value with '/' and '/' to perform a regular expression search rather than a containment operation. Any record that matches will be returned. The attributes searched are: DataSourceID, DeviceID, DeviceZoneID, IfZoneID, InterfaceID, ifZoneChangedCols, ifZoneEndTime, ifZoneFirstSeenTime, ifZoneStartTime, ifZoneTimestamp.
             :type query: String

            |  ``api version min:`` 2.3
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param xml_filter: A SetFilter XML structure to further refine the search. The SetFilter will be applied AFTER any search query or field values, but before any limit options. The limit and pagination will be enforced after the filter. Remind that this kind of filter may be costly and inefficient if not associated with a database filtering.
             :type xml_filter: String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return if_zones: An array of the IfZone objects that match the specified input criteria.
             :rtype if_zones: Array of IfZone

            """

        return self.api_list_request(self._get_method_fullname("search"), kwargs)

    def find(self, **kwargs):
        """Lists the available if zones matching the input specification. This provides the most flexible search specification of all the query mechanisms, enabling searching using comparison operations other than equality. However, it is more complex to use and will not perform as efficiently as the index or search methods. In the input descriptions below, 'field names' refers to the following fields: DataSourceID, DeviceID, DeviceZoneID, IfZoneID, InterfaceID, ifZoneChangedCols, ifZoneEndTime, ifZoneFirstSeenTime, ifZoneStartTime, ifZoneTimestamp.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_DataSourceID: The operator to apply to the field DataSourceID. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. DataSourceID: The internal NetMRI identifier for the collector NetMRI that collected this data record. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_DataSourceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_DataSourceID: If op_DataSourceID is specified, the field named in this input will be compared to the value in DataSourceID using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_DataSourceID must be specified if op_DataSourceID is specified.
             :type val_f_DataSourceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_DataSourceID: If op_DataSourceID is specified, this value will be compared to the value in DataSourceID using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_DataSourceID must be specified if op_DataSourceID is specified.
             :type val_c_DataSourceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_DeviceID: The operator to apply to the field DeviceID. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. DeviceID: The internal NetMRI identifier for the device for which belongs Zone and Interface. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_DeviceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_DeviceID: If op_DeviceID is specified, the field named in this input will be compared to the value in DeviceID using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_DeviceID must be specified if op_DeviceID is specified.
             :type val_f_DeviceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_DeviceID: If op_DeviceID is specified, this value will be compared to the value in DeviceID using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_DeviceID must be specified if op_DeviceID is specified.
             :type val_c_DeviceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_DeviceZoneID: The operator to apply to the field DeviceZoneID. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. DeviceZoneID: The internal NetMRI identifier of the Zone. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_DeviceZoneID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_DeviceZoneID: If op_DeviceZoneID is specified, the field named in this input will be compared to the value in DeviceZoneID using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_DeviceZoneID must be specified if op_DeviceZoneID is specified.
             :type val_f_DeviceZoneID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_DeviceZoneID: If op_DeviceZoneID is specified, this value will be compared to the value in DeviceZoneID using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_DeviceZoneID must be specified if op_DeviceZoneID is specified.
             :type val_c_DeviceZoneID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_IfZoneID: The operator to apply to the field IfZoneID. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. IfZoneID: The internal NetMRI identifier for this relation between a Zone and an Interface of device. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_IfZoneID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_IfZoneID: If op_IfZoneID is specified, the field named in this input will be compared to the value in IfZoneID using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_IfZoneID must be specified if op_IfZoneID is specified.
             :type val_f_IfZoneID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_IfZoneID: If op_IfZoneID is specified, this value will be compared to the value in IfZoneID using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_IfZoneID must be specified if op_IfZoneID is specified.
             :type val_c_IfZoneID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_InterfaceID: The operator to apply to the field InterfaceID. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. InterfaceID: The internal NetMRI identifier of the Interface of the device. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_InterfaceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_InterfaceID: If op_InterfaceID is specified, the field named in this input will be compared to the value in InterfaceID using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_InterfaceID must be specified if op_InterfaceID is specified.
             :type val_f_InterfaceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_InterfaceID: If op_InterfaceID is specified, this value will be compared to the value in InterfaceID using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_InterfaceID must be specified if op_InterfaceID is specified.
             :type val_c_InterfaceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_ifZoneChangedCols: The operator to apply to the field ifZoneChangedCols. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. ifZoneChangedCols: The fields that changed between this revision of the record and the previous revision. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_ifZoneChangedCols: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_ifZoneChangedCols: If op_ifZoneChangedCols is specified, the field named in this input will be compared to the value in ifZoneChangedCols using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_ifZoneChangedCols must be specified if op_ifZoneChangedCols is specified.
             :type val_f_ifZoneChangedCols: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_ifZoneChangedCols: If op_ifZoneChangedCols is specified, this value will be compared to the value in ifZoneChangedCols using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_ifZoneChangedCols must be specified if op_ifZoneChangedCols is specified.
             :type val_c_ifZoneChangedCols: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_ifZoneEndTime: The operator to apply to the field ifZoneEndTime. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. ifZoneEndTime: The ending effective time of this record, or empty if still in effect. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_ifZoneEndTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_ifZoneEndTime: If op_ifZoneEndTime is specified, the field named in this input will be compared to the value in ifZoneEndTime using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_ifZoneEndTime must be specified if op_ifZoneEndTime is specified.
             :type val_f_ifZoneEndTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_ifZoneEndTime: If op_ifZoneEndTime is specified, this value will be compared to the value in ifZoneEndTime using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_ifZoneEndTime must be specified if op_ifZoneEndTime is specified.
             :type val_c_ifZoneEndTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_ifZoneFirstSeenTime: The operator to apply to the field ifZoneFirstSeenTime. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. ifZoneFirstSeenTime: The timestamp of when NetMRI saw for the first time this relationship. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_ifZoneFirstSeenTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_ifZoneFirstSeenTime: If op_ifZoneFirstSeenTime is specified, the field named in this input will be compared to the value in ifZoneFirstSeenTime using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_ifZoneFirstSeenTime must be specified if op_ifZoneFirstSeenTime is specified.
             :type val_f_ifZoneFirstSeenTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_ifZoneFirstSeenTime: If op_ifZoneFirstSeenTime is specified, this value will be compared to the value in ifZoneFirstSeenTime using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_ifZoneFirstSeenTime must be specified if op_ifZoneFirstSeenTime is specified.
             :type val_c_ifZoneFirstSeenTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_ifZoneStartTime: The operator to apply to the field ifZoneStartTime. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. ifZoneStartTime: The starting effective time of this record. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_ifZoneStartTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_ifZoneStartTime: If op_ifZoneStartTime is specified, the field named in this input will be compared to the value in ifZoneStartTime using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_ifZoneStartTime must be specified if op_ifZoneStartTime is specified.
             :type val_f_ifZoneStartTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_ifZoneStartTime: If op_ifZoneStartTime is specified, this value will be compared to the value in ifZoneStartTime using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_ifZoneStartTime must be specified if op_ifZoneStartTime is specified.
             :type val_c_ifZoneStartTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_ifZoneTimestamp: The operator to apply to the field ifZoneTimestamp. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. ifZoneTimestamp: The date and time this record was collected or calculated. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_ifZoneTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_ifZoneTimestamp: If op_ifZoneTimestamp is specified, the field named in this input will be compared to the value in ifZoneTimestamp using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_ifZoneTimestamp must be specified if op_ifZoneTimestamp is specified.
             :type val_f_ifZoneTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_ifZoneTimestamp: If op_ifZoneTimestamp is specified, this value will be compared to the value in ifZoneTimestamp using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_ifZoneTimestamp must be specified if op_ifZoneTimestamp is specified.
             :type val_c_ifZoneTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceGroupID: The internal NetMRI identifier of the device groups to which to limit the results.
             :type DeviceGroupID: Array of Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param timestamp: The data returned will represent the if zones as of this date and time. If omitted, the result will indicate the most recently collected data.
             :type timestamp: DateTime

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param methods: A list of if zone methods. The listed methods will be called on each if zone returned and included in the output. Available methods are: device_zone, data_source, device.
             :type methods: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param include: A list of associated object types to include in the output. The listed associations will be returned as outputs named according to the association name (see outputs below). Available includes are: device_zone, data_source, device.
             :type include: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param start: The record number to return in the selected page of data. It will always appear, although it may not be the first record. See the :limit for more information.
             :type start: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 1000

             :param limit: The size of the page of data, that is, the maximum number of records returned. The limit size will be used to break the data up into pages and the first page with the start record will be returned. So if you have 100 records and use a :limit of 10 and a :start of 10, you will get records 10-19. The maximum limit is 10000.
             :type limit: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` IfZoneID

             :param sort: The data field(s) to use for sorting the output. Default is IfZoneID. Valid values are IfZoneID, DeviceID, DataSourceID, DeviceZoneID, InterfaceID, ifZoneFirstSeenTime, ifZoneStartTime, ifZoneEndTime, ifZoneTimestamp, ifZoneChangedCols.
             :type sort: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` asc

             :param dir: The direction(s) in which to sort the data. Default is 'asc'. Valid values are 'asc' and 'desc'.
             :type dir: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param select: The list of attributes to return for each IfZone. Valid values are IfZoneID, DeviceID, DataSourceID, DeviceZoneID, InterfaceID, ifZoneFirstSeenTime, ifZoneStartTime, ifZoneEndTime, ifZoneTimestamp, ifZoneChangedCols. If empty or omitted, all attributes will be returned.
             :type select: Array

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_field: The field name for NIOS GOTO that is used for locating a row position of records.
             :type goto_field: String

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_value: The value of goto_field for NIOS GOTO that is used for locating a row position of records.
             :type goto_value: String

            |  ``api version min:`` 2.3
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param xml_filter: A SetFilter XML structure to further refine the search. The SetFilter will be applied AFTER any search query or field values, but before any limit options. The limit and pagination will be enforced after the filter. Remind that this kind of filter may be costly and inefficient if not associated with a database filtering.
             :type xml_filter: String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return if_zones: An array of the IfZone objects that match the specified input criteria.
             :rtype if_zones: Array of IfZone

            """

        return self.api_list_request(self._get_method_fullname("find"), kwargs)

    def device_zone(self, **kwargs):
        """The DeviceZone part of this relationship.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param IfZoneID: The internal NetMRI identifier for this relation between a Zone and an Interface of device.
             :type IfZoneID: Integer

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return : The DeviceZone part of this relationship.
             :rtype : DeviceZone

            """

        return self.api_request(self._get_method_fullname("device_zone"), kwargs)

    def data_source(self, **kwargs):
        """The collector NetMRI that collected this data record.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param IfZoneID: The internal NetMRI identifier for this relation between a Zone and an Interface of device.
             :type IfZoneID: Integer

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return : The collector NetMRI that collected this data record.
             :rtype : DataSource

            """

        return self.api_request(self._get_method_fullname("data_source"), kwargs)

    def device(self, **kwargs):
        """The device from which this data was collected.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param IfZoneID: The internal NetMRI identifier for this relation between a Zone and an Interface of device.
             :type IfZoneID: Integer

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return : The device from which this data was collected.
             :rtype : Device

            """

        return self.api_request(self._get_method_fullname("device"), kwargs)



from ..broker import Broker


class SdnSettingBroker(Broker):
    controller = "sdn_settings"

    def index(self, **kwargs):
        """Lists the available sdn settings. Any of the inputs listed may be be used to narrow the list; other inputs will be ignored. Of the various ways to query lists, using this method is most efficient.

            **Inputs**

            |  ``api version min:`` 3.4
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param id: The internal NetMRI identifier for this setting.
             :type id: Array of Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param start: The record number to return in the selected page of data. It will always appear, although it may not be the first record. See the :limit for more information.
             :type start: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 1000

             :param limit: The size of the page of data, that is, the maximum number of records returned. The limit size will be used to break the data up into pages and the first page with the start record will be returned. So if you have 100 records and use a :limit of 10 and a :start of 10, you will get records 10-19. The maximum limit is 10000.
             :type limit: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` id

             :param sort: The data field(s) to use for sorting the output. Default is id. Valid values are id, virtual_network_id, controller_address, protocol, sdn_username, sdn_password, SecureVersion, created_at, updated_at, UnitID, sdn_type, api_key, on_prem, use_global_proxy, handle, scan_interface_id, start_blackout_schedule, blackout_duration, max_requests_per_second, collect_offline_devices, ca_cert_id, ca_cert_content.
             :type sort: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` asc

             :param dir: The direction(s) in which to sort the data. Default is 'asc'. Valid values are 'asc' and 'desc'.
             :type dir: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param select: The list of attributes to return for each SdnSetting. Valid values are id, virtual_network_id, controller_address, protocol, sdn_username, sdn_password, SecureVersion, created_at, updated_at, UnitID, sdn_type, api_key, on_prem, use_global_proxy, handle, scan_interface_id, start_blackout_schedule, blackout_duration, max_requests_per_second, collect_offline_devices, ca_cert_id, ca_cert_content. If empty or omitted, all attributes will be returned.
             :type select: Array

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_field: The field name for NIOS GOTO that is used for locating a row position of records.
             :type goto_field: String

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_value: The value of goto_field for NIOS GOTO that is used for locating a row position of records.
             :type goto_value: String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return sdn_settings: An array of the SdnSetting objects that match the specified input criteria.
             :rtype sdn_settings: Array of SdnSetting

            """

        return self.api_list_request(self._get_method_fullname("index"), kwargs)

    def search(self, **kwargs):
        """Lists the available sdn settings matching the input criteria. This method provides a more flexible search interface than the index method, but searching using this method is more demanding on the system and will not perform to the same level as the index method. The input fields listed below will be used as in the index method, to filter the result, along with the optional query string and XML filter described below.

            **Inputs**

            |  ``api version min:`` 3.4
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param SecureVersion: Internal version of the encryption method
             :type SecureVersion: Array of Integer

            |  ``api version min:`` 3.4
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param UnitID: The internal NetMRI identifier for collector assigned to the SDN Setting
             :type UnitID: Array of Integer

            |  ``api version min:`` 3.4
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param api_key: API key to access the SDN controller (MERAKI)
             :type api_key: Array of String

            |  ``api version min:`` 3.4
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param blackout_duration: The blackout duration in minutes.
             :type blackout_duration: Array of Integer

            |  ``api version min:`` 3.4
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param ca_cert_content: Content of custom CA certificate.
             :type ca_cert_content: Array of String

            |  ``api version min:`` 3.4
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param ca_cert_id: ID of custom CA certificate.
             :type ca_cert_id: Array of Integer

            |  ``api version min:`` 3.4
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param collect_offline_devices: Collect Devices In Offline Status
             :type collect_offline_devices: Array of Boolean

            |  ``api version min:`` 3.4
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param controller_address: Controller IP address or hostname.
             :type controller_address: Array of String

            |  ``api version min:`` 3.4
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param created_at: The date and time when the record was initially created in NetMRI.
             :type created_at: Array of DateTime

            |  ``api version min:`` 3.4
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param handle: Unique handle for single configuration
             :type handle: Array of String

            |  ``api version min:`` 3.4
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param id: The internal NetMRI identifier for this setting.
             :type id: Array of Integer

            |  ``api version min:`` 3.4
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param max_requests_per_second: Maximum Requests per Second.
             :type max_requests_per_second: Array of Integer

            |  ``api version min:`` 3.4
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param on_prem: True if controller is on premises. Otherwise we consider it is in cloud.
             :type on_prem: Array of Boolean

            |  ``api version min:`` 3.4
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param protocol: Protocol used to communicate with controller.
             :type protocol: Array of String

            |  ``api version min:`` 3.4
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param scan_interface_id: ID of scan interface which used for controller connection
             :type scan_interface_id: Array of Integer

            |  ``api version min:`` 3.4
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param sdn_password: Password used to connect SDN controller.
             :type sdn_password: Array of String

            |  ``api version min:`` 3.4
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param sdn_type: Type of SDN controller. Allowed values are CISCO_APIC, MERAKI, VELOCLOUD, SILVER_PEAK, VIPTELA
             :type sdn_type: Array of String

            |  ``api version min:`` 3.4
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param sdn_username: Username used to connect SDN controller.
             :type sdn_username: Array of String

            |  ``api version min:`` 3.4
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param start_blackout_schedule: The blackout start time in cron format.
             :type start_blackout_schedule: Array of String

            |  ``api version min:`` 3.4
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param updated_at: The date and time when the record was last modified in NetMRI.
             :type updated_at: Array of DateTime

            |  ``api version min:`` 3.4
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param use_global_proxy: Use global proxy settings to access SDN controller.
             :type use_global_proxy: Array of Boolean

            |  ``api version min:`` 3.4
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param virtual_network_id: The internal NetMRI identifier of the Virtual Network on which this controller is defined.
             :type virtual_network_id: Array of Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param start: The record number to return in the selected page of data. It will always appear, although it may not be the first record. See the :limit for more information.
             :type start: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 1000

             :param limit: The size of the page of data, that is, the maximum number of records returned. The limit size will be used to break the data up into pages and the first page with the start record will be returned. So if you have 100 records and use a :limit of 10 and a :start of 10, you will get records 10-19. The maximum limit is 10000.
             :type limit: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` id

             :param sort: The data field(s) to use for sorting the output. Default is id. Valid values are id, virtual_network_id, controller_address, protocol, sdn_username, sdn_password, SecureVersion, created_at, updated_at, UnitID, sdn_type, api_key, on_prem, use_global_proxy, handle, scan_interface_id, start_blackout_schedule, blackout_duration, max_requests_per_second, collect_offline_devices, ca_cert_id, ca_cert_content.
             :type sort: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` asc

             :param dir: The direction(s) in which to sort the data. Default is 'asc'. Valid values are 'asc' and 'desc'.
             :type dir: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param select: The list of attributes to return for each SdnSetting. Valid values are id, virtual_network_id, controller_address, protocol, sdn_username, sdn_password, SecureVersion, created_at, updated_at, UnitID, sdn_type, api_key, on_prem, use_global_proxy, handle, scan_interface_id, start_blackout_schedule, blackout_duration, max_requests_per_second, collect_offline_devices, ca_cert_id, ca_cert_content. If empty or omitted, all attributes will be returned.
             :type select: Array

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_field: The field name for NIOS GOTO that is used for locating a row position of records.
             :type goto_field: String

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_value: The value of goto_field for NIOS GOTO that is used for locating a row position of records.
             :type goto_value: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param query: This value will be matched against sdn settings, looking to see if one or more of the listed attributes contain the passed value. You may also surround the value with '/' and '/' to perform a regular expression search rather than a containment operation. Any record that matches will be returned. The attributes searched are: SecureVersion, UnitID, api_key, blackout_duration, ca_cert_content, ca_cert_id, collect_offline_devices, controller_address, created_at, handle, id, max_requests_per_second, on_prem, protocol, scan_interface_id, sdn_password, sdn_type, sdn_username, start_blackout_schedule, updated_at, use_global_proxy, virtual_network_id.
             :type query: String

            |  ``api version min:`` 2.3
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param xml_filter: A SetFilter XML structure to further refine the search. The SetFilter will be applied AFTER any search query or field values, but before any limit options. The limit and pagination will be enforced after the filter. Remind that this kind of filter may be costly and inefficient if not associated with a database filtering.
             :type xml_filter: String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return sdn_settings: An array of the SdnSetting objects that match the specified input criteria.
             :rtype sdn_settings: Array of SdnSetting

            """

        return self.api_list_request(self._get_method_fullname("search"), kwargs)

    def find(self, **kwargs):
        """Lists the available sdn settings matching the input specification. This provides the most flexible search specification of all the query mechanisms, enabling searching using comparison operations other than equality. However, it is more complex to use and will not perform as efficiently as the index or search methods. In the input descriptions below, 'field names' refers to the following fields: SecureVersion, UnitID, api_key, blackout_duration, ca_cert_content, ca_cert_id, collect_offline_devices, controller_address, created_at, handle, id, max_requests_per_second, on_prem, protocol, scan_interface_id, sdn_password, sdn_type, sdn_username, start_blackout_schedule, updated_at, use_global_proxy, virtual_network_id.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_SecureVersion: The operator to apply to the field SecureVersion. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. SecureVersion: Internal version of the encryption method For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_SecureVersion: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_SecureVersion: If op_SecureVersion is specified, the field named in this input will be compared to the value in SecureVersion using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_SecureVersion must be specified if op_SecureVersion is specified.
             :type val_f_SecureVersion: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_SecureVersion: If op_SecureVersion is specified, this value will be compared to the value in SecureVersion using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_SecureVersion must be specified if op_SecureVersion is specified.
             :type val_c_SecureVersion: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_UnitID: The operator to apply to the field UnitID. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. UnitID: The internal NetMRI identifier for collector assigned to the SDN Setting For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_UnitID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_UnitID: If op_UnitID is specified, the field named in this input will be compared to the value in UnitID using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_UnitID must be specified if op_UnitID is specified.
             :type val_f_UnitID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_UnitID: If op_UnitID is specified, this value will be compared to the value in UnitID using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_UnitID must be specified if op_UnitID is specified.
             :type val_c_UnitID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_api_key: The operator to apply to the field api_key. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. api_key: API key to access the SDN controller (MERAKI) For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_api_key: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_api_key: If op_api_key is specified, the field named in this input will be compared to the value in api_key using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_api_key must be specified if op_api_key is specified.
             :type val_f_api_key: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_api_key: If op_api_key is specified, this value will be compared to the value in api_key using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_api_key must be specified if op_api_key is specified.
             :type val_c_api_key: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_blackout_duration: The operator to apply to the field blackout_duration. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. blackout_duration: The blackout duration in minutes. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_blackout_duration: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_blackout_duration: If op_blackout_duration is specified, the field named in this input will be compared to the value in blackout_duration using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_blackout_duration must be specified if op_blackout_duration is specified.
             :type val_f_blackout_duration: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_blackout_duration: If op_blackout_duration is specified, this value will be compared to the value in blackout_duration using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_blackout_duration must be specified if op_blackout_duration is specified.
             :type val_c_blackout_duration: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_ca_cert_content: The operator to apply to the field ca_cert_content. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. ca_cert_content: Content of custom CA certificate. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_ca_cert_content: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_ca_cert_content: If op_ca_cert_content is specified, the field named in this input will be compared to the value in ca_cert_content using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_ca_cert_content must be specified if op_ca_cert_content is specified.
             :type val_f_ca_cert_content: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_ca_cert_content: If op_ca_cert_content is specified, this value will be compared to the value in ca_cert_content using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_ca_cert_content must be specified if op_ca_cert_content is specified.
             :type val_c_ca_cert_content: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_ca_cert_id: The operator to apply to the field ca_cert_id. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. ca_cert_id: ID of custom CA certificate. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_ca_cert_id: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_ca_cert_id: If op_ca_cert_id is specified, the field named in this input will be compared to the value in ca_cert_id using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_ca_cert_id must be specified if op_ca_cert_id is specified.
             :type val_f_ca_cert_id: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_ca_cert_id: If op_ca_cert_id is specified, this value will be compared to the value in ca_cert_id using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_ca_cert_id must be specified if op_ca_cert_id is specified.
             :type val_c_ca_cert_id: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_collect_offline_devices: The operator to apply to the field collect_offline_devices. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. collect_offline_devices: Collect Devices In Offline Status For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_collect_offline_devices: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_collect_offline_devices: If op_collect_offline_devices is specified, the field named in this input will be compared to the value in collect_offline_devices using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_collect_offline_devices must be specified if op_collect_offline_devices is specified.
             :type val_f_collect_offline_devices: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_collect_offline_devices: If op_collect_offline_devices is specified, this value will be compared to the value in collect_offline_devices using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_collect_offline_devices must be specified if op_collect_offline_devices is specified.
             :type val_c_collect_offline_devices: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_controller_address: The operator to apply to the field controller_address. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. controller_address: Controller IP address or hostname. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_controller_address: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_controller_address: If op_controller_address is specified, the field named in this input will be compared to the value in controller_address using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_controller_address must be specified if op_controller_address is specified.
             :type val_f_controller_address: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_controller_address: If op_controller_address is specified, this value will be compared to the value in controller_address using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_controller_address must be specified if op_controller_address is specified.
             :type val_c_controller_address: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_created_at: The operator to apply to the field created_at. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. created_at: The date and time when the record was initially created in NetMRI. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_created_at: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_created_at: If op_created_at is specified, the field named in this input will be compared to the value in created_at using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_created_at must be specified if op_created_at is specified.
             :type val_f_created_at: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_created_at: If op_created_at is specified, this value will be compared to the value in created_at using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_created_at must be specified if op_created_at is specified.
             :type val_c_created_at: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_handle: The operator to apply to the field handle. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. handle: Unique handle for single configuration For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_handle: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_handle: If op_handle is specified, the field named in this input will be compared to the value in handle using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_handle must be specified if op_handle is specified.
             :type val_f_handle: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_handle: If op_handle is specified, this value will be compared to the value in handle using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_handle must be specified if op_handle is specified.
             :type val_c_handle: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_id: The operator to apply to the field id. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. id: The internal NetMRI identifier for this setting. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_id: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_id: If op_id is specified, the field named in this input will be compared to the value in id using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_id must be specified if op_id is specified.
             :type val_f_id: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_id: If op_id is specified, this value will be compared to the value in id using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_id must be specified if op_id is specified.
             :type val_c_id: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_max_requests_per_second: The operator to apply to the field max_requests_per_second. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. max_requests_per_second: Maximum Requests per Second. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_max_requests_per_second: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_max_requests_per_second: If op_max_requests_per_second is specified, the field named in this input will be compared to the value in max_requests_per_second using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_max_requests_per_second must be specified if op_max_requests_per_second is specified.
             :type val_f_max_requests_per_second: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_max_requests_per_second: If op_max_requests_per_second is specified, this value will be compared to the value in max_requests_per_second using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_max_requests_per_second must be specified if op_max_requests_per_second is specified.
             :type val_c_max_requests_per_second: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_on_prem: The operator to apply to the field on_prem. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. on_prem: True if controller is on premises. Otherwise we consider it is in cloud. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_on_prem: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_on_prem: If op_on_prem is specified, the field named in this input will be compared to the value in on_prem using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_on_prem must be specified if op_on_prem is specified.
             :type val_f_on_prem: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_on_prem: If op_on_prem is specified, this value will be compared to the value in on_prem using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_on_prem must be specified if op_on_prem is specified.
             :type val_c_on_prem: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_protocol: The operator to apply to the field protocol. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. protocol: Protocol used to communicate with controller. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_protocol: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_protocol: If op_protocol is specified, the field named in this input will be compared to the value in protocol using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_protocol must be specified if op_protocol is specified.
             :type val_f_protocol: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_protocol: If op_protocol is specified, this value will be compared to the value in protocol using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_protocol must be specified if op_protocol is specified.
             :type val_c_protocol: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_scan_interface_id: The operator to apply to the field scan_interface_id. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. scan_interface_id: ID of scan interface which used for controller connection For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_scan_interface_id: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_scan_interface_id: If op_scan_interface_id is specified, the field named in this input will be compared to the value in scan_interface_id using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_scan_interface_id must be specified if op_scan_interface_id is specified.
             :type val_f_scan_interface_id: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_scan_interface_id: If op_scan_interface_id is specified, this value will be compared to the value in scan_interface_id using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_scan_interface_id must be specified if op_scan_interface_id is specified.
             :type val_c_scan_interface_id: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_sdn_password: The operator to apply to the field sdn_password. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. sdn_password: Password used to connect SDN controller. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_sdn_password: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_sdn_password: If op_sdn_password is specified, the field named in this input will be compared to the value in sdn_password using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_sdn_password must be specified if op_sdn_password is specified.
             :type val_f_sdn_password: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_sdn_password: If op_sdn_password is specified, this value will be compared to the value in sdn_password using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_sdn_password must be specified if op_sdn_password is specified.
             :type val_c_sdn_password: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_sdn_type: The operator to apply to the field sdn_type. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. sdn_type: Type of SDN controller. Allowed values are CISCO_APIC, MERAKI, VELOCLOUD, SILVER_PEAK, VIPTELA For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_sdn_type: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_sdn_type: If op_sdn_type is specified, the field named in this input will be compared to the value in sdn_type using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_sdn_type must be specified if op_sdn_type is specified.
             :type val_f_sdn_type: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_sdn_type: If op_sdn_type is specified, this value will be compared to the value in sdn_type using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_sdn_type must be specified if op_sdn_type is specified.
             :type val_c_sdn_type: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_sdn_username: The operator to apply to the field sdn_username. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. sdn_username: Username used to connect SDN controller. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_sdn_username: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_sdn_username: If op_sdn_username is specified, the field named in this input will be compared to the value in sdn_username using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_sdn_username must be specified if op_sdn_username is specified.
             :type val_f_sdn_username: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_sdn_username: If op_sdn_username is specified, this value will be compared to the value in sdn_username using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_sdn_username must be specified if op_sdn_username is specified.
             :type val_c_sdn_username: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_start_blackout_schedule: The operator to apply to the field start_blackout_schedule. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. start_blackout_schedule: The blackout start time in cron format. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_start_blackout_schedule: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_start_blackout_schedule: If op_start_blackout_schedule is specified, the field named in this input will be compared to the value in start_blackout_schedule using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_start_blackout_schedule must be specified if op_start_blackout_schedule is specified.
             :type val_f_start_blackout_schedule: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_start_blackout_schedule: If op_start_blackout_schedule is specified, this value will be compared to the value in start_blackout_schedule using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_start_blackout_schedule must be specified if op_start_blackout_schedule is specified.
             :type val_c_start_blackout_schedule: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_updated_at: The operator to apply to the field updated_at. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. updated_at: The date and time when the record was last modified in NetMRI. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_updated_at: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_updated_at: If op_updated_at is specified, the field named in this input will be compared to the value in updated_at using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_updated_at must be specified if op_updated_at is specified.
             :type val_f_updated_at: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_updated_at: If op_updated_at is specified, this value will be compared to the value in updated_at using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_updated_at must be specified if op_updated_at is specified.
             :type val_c_updated_at: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_use_global_proxy: The operator to apply to the field use_global_proxy. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. use_global_proxy: Use global proxy settings to access SDN controller. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_use_global_proxy: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_use_global_proxy: If op_use_global_proxy is specified, the field named in this input will be compared to the value in use_global_proxy using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_use_global_proxy must be specified if op_use_global_proxy is specified.
             :type val_f_use_global_proxy: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_use_global_proxy: If op_use_global_proxy is specified, this value will be compared to the value in use_global_proxy using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_use_global_proxy must be specified if op_use_global_proxy is specified.
             :type val_c_use_global_proxy: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_virtual_network_id: The operator to apply to the field virtual_network_id. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. virtual_network_id: The internal NetMRI identifier of the Virtual Network on which this controller is defined. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_virtual_network_id: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_virtual_network_id: If op_virtual_network_id is specified, the field named in this input will be compared to the value in virtual_network_id using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_virtual_network_id must be specified if op_virtual_network_id is specified.
             :type val_f_virtual_network_id: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_virtual_network_id: If op_virtual_network_id is specified, this value will be compared to the value in virtual_network_id using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_virtual_network_id must be specified if op_virtual_network_id is specified.
             :type val_c_virtual_network_id: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param start: The record number to return in the selected page of data. It will always appear, although it may not be the first record. See the :limit for more information.
             :type start: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 1000

             :param limit: The size of the page of data, that is, the maximum number of records returned. The limit size will be used to break the data up into pages and the first page with the start record will be returned. So if you have 100 records and use a :limit of 10 and a :start of 10, you will get records 10-19. The maximum limit is 10000.
             :type limit: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` id

             :param sort: The data field(s) to use for sorting the output. Default is id. Valid values are id, virtual_network_id, controller_address, protocol, sdn_username, sdn_password, SecureVersion, created_at, updated_at, UnitID, sdn_type, api_key, on_prem, use_global_proxy, handle, scan_interface_id, start_blackout_schedule, blackout_duration, max_requests_per_second, collect_offline_devices, ca_cert_id, ca_cert_content.
             :type sort: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` asc

             :param dir: The direction(s) in which to sort the data. Default is 'asc'. Valid values are 'asc' and 'desc'.
             :type dir: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param select: The list of attributes to return for each SdnSetting. Valid values are id, virtual_network_id, controller_address, protocol, sdn_username, sdn_password, SecureVersion, created_at, updated_at, UnitID, sdn_type, api_key, on_prem, use_global_proxy, handle, scan_interface_id, start_blackout_schedule, blackout_duration, max_requests_per_second, collect_offline_devices, ca_cert_id, ca_cert_content. If empty or omitted, all attributes will be returned.
             :type select: Array

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_field: The field name for NIOS GOTO that is used for locating a row position of records.
             :type goto_field: String

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_value: The value of goto_field for NIOS GOTO that is used for locating a row position of records.
             :type goto_value: String

            |  ``api version min:`` 2.3
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param xml_filter: A SetFilter XML structure to further refine the search. The SetFilter will be applied AFTER any search query or field values, but before any limit options. The limit and pagination will be enforced after the filter. Remind that this kind of filter may be costly and inefficient if not associated with a database filtering.
             :type xml_filter: String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return sdn_settings: An array of the SdnSetting objects that match the specified input criteria.
             :rtype sdn_settings: Array of SdnSetting

            """

        return self.api_list_request(self._get_method_fullname("find"), kwargs)

    def show(self, **kwargs):
        """Shows the details for the specified sdn setting.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param id: The internal NetMRI identifier for this setting.
             :type id: Integer

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return sdn_setting: The sdn setting identified by the specified id.
             :rtype sdn_setting: SdnSetting

            """

        return self.api_request(self._get_method_fullname("show"), kwargs)

    def create(self, **kwargs):
        """Creates a new sdn setting.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 1

             :param SecureVersion: Internal version of the encryption method
             :type SecureVersion: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param UnitID: The internal NetMRI identifier for collector assigned to the SDN Setting
             :type UnitID: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param api_key: API key to access the SDN controller (MERAKI)
             :type api_key: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param blackout_duration: The blackout duration in minutes.
             :type blackout_duration: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param ca_cert_content: Content of custom CA certificate.
             :type ca_cert_content: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param ca_cert_id: ID of custom CA certificate.
             :type ca_cert_id: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` True

             :param collect_offline_devices: Collect Devices In Offline Status
             :type collect_offline_devices: Boolean

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param controller_address: Controller IP address or hostname.
             :type controller_address: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param handle: Unique handle for single configuration
             :type handle: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param max_requests_per_second: Maximum Requests per Second.
             :type max_requests_per_second: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param on_prem: True if controller is on premises. Otherwise we consider it is in cloud.
             :type on_prem: Boolean

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param protocol: Protocol used to communicate with controller.
             :type protocol: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param scan_interface_id: ID of scan interface which used for controller connection
             :type scan_interface_id: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param sdn_password: Password used to connect SDN controller.
             :type sdn_password: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param sdn_type: Type of SDN controller. Allowed values are CISCO_APIC, MERAKI, VELOCLOUD, SILVER_PEAK, VIPTELA
             :type sdn_type: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param sdn_username: Username used to connect SDN controller.
             :type sdn_username: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:``

             :param start_blackout_schedule: The blackout start time in cron format.
             :type start_blackout_schedule: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param use_global_proxy: Use global proxy settings to access SDN controller.
             :type use_global_proxy: Boolean

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param virtual_network_id: The internal NetMRI identifier of the Virtual Network on which this controller is defined.
             :type virtual_network_id: Integer

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return id: The id of the newly created sdn setting.
             :rtype id: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return model: The class name of the newly created sdn setting.
             :rtype model: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return uri: A URI that may be used to retrieve the newly created sdn setting.
             :rtype uri: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return sdn_setting: The newly created sdn setting.
             :rtype sdn_setting: SdnSetting

            """

        return self.api_request(self._get_method_fullname("create"), kwargs)

    def update(self, **kwargs):
        """Updates an existing sdn setting.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param id: The internal NetMRI identifier for this setting.
             :type id: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 1

             :param SecureVersion: Internal version of the encryption method If omitted, this field will be updated to the default value.
             :type SecureVersion: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param UnitID: The internal NetMRI identifier for collector assigned to the SDN Setting If omitted, this field will be updated to the default value.
             :type UnitID: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param api_key: API key to access the SDN controller (MERAKI) If omitted, this field will not be updated.
             :type api_key: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param blackout_duration: The blackout duration in minutes. If omitted, this field will be updated to the default value.
             :type blackout_duration: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param ca_cert_content: Content of custom CA certificate. If omitted, this field will not be updated.
             :type ca_cert_content: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param ca_cert_id: ID of custom CA certificate. If omitted, this field will not be updated.
             :type ca_cert_id: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` True

             :param collect_offline_devices: Collect Devices In Offline Status If omitted, this field will be updated to the default value.
             :type collect_offline_devices: Boolean

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param controller_address: Controller IP address or hostname. If omitted, this field will not be updated.
             :type controller_address: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param handle: Unique handle for single configuration If omitted, this field will not be updated.
             :type handle: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param max_requests_per_second: Maximum Requests per Second. If omitted, this field will be updated to the default value.
             :type max_requests_per_second: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param on_prem: True if controller is on premises. Otherwise we consider it is in cloud. If omitted, this field will not be updated.
             :type on_prem: Boolean

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param protocol: Protocol used to communicate with controller. If omitted, this field will not be updated.
             :type protocol: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param scan_interface_id: ID of scan interface which used for controller connection If omitted, this field will not be updated.
             :type scan_interface_id: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param sdn_password: Password used to connect SDN controller. If omitted, this field will not be updated.
             :type sdn_password: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param sdn_type: Type of SDN controller. Allowed values are CISCO_APIC, MERAKI, VELOCLOUD, SILVER_PEAK, VIPTELA If omitted, this field will not be updated.
             :type sdn_type: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param sdn_username: Username used to connect SDN controller. If omitted, this field will not be updated.
             :type sdn_username: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:``

             :param start_blackout_schedule: The blackout start time in cron format. If omitted, this field will be updated to the default value.
             :type start_blackout_schedule: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param use_global_proxy: Use global proxy settings to access SDN controller. If omitted, this field will not be updated.
             :type use_global_proxy: Boolean

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param virtual_network_id: The internal NetMRI identifier of the Virtual Network on which this controller is defined. If omitted, this field will not be updated.
             :type virtual_network_id: Integer

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return id: The id of the updated sdn setting.
             :rtype id: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return model: The class name of the updated sdn setting.
             :rtype model: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return uri: A URI that may be used to retrieve the updated sdn setting.
             :rtype uri: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return sdn_setting: The updated sdn setting.
             :rtype sdn_setting: SdnSetting

            """

        return self.api_request(self._get_method_fullname("update"), kwargs)

    def destroy(self, **kwargs):
        """Deletes the specified sdn setting from NetMRI.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param id: The internal NetMRI identifier for this setting.
             :type id: Integer

            **Outputs**

            """

        return self.api_request(self._get_method_fullname("destroy"), kwargs)

    def destroy_many(self, **kwargs):
        """Remove several configurations of SDN Controllers

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param ids: The IDs array of the configurations.  When sending form encoded use ids[].
             :type ids: Array

            **Outputs**

            """

        return self.api_request(self._get_method_fullname("destroy_many"), kwargs)

    def dump_sdn_controllers(self, **kwargs):
        """List all SDN Controllers

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` controller_address

             :param sort: The data field to use for sorting the output. Default is controller_address.
             :type sort: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` asc

             :param dir: The direction in which to sort the data. Default is 'asc'. Valid values are 'asc' and 'desc'.
             :type dir: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param UnitID: The UnitID of the collector
             :type UnitID: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param query: This value will be matched against attribute "controller_address" and "VirtualNetworkName". Any SdnSetting objects with the passed value contained within one or more of those attributes will be returned.
             :type query: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param start: The record number to return in the selected page of data. It will always appear, although it may not be the first record. See the :limit for more information.
             :type start: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param limit: The size of the page of data, that is, the maximum number of records returned. The limit size will be used to break the data up into pages and the first page with the start record will be returned. So if you have 100 records and use a :limit of 10 and a :start of 10, you will get records 10-19.
             :type limit: Integer

            **Outputs**

            """

        return self.api_request(self._get_method_fullname("dump_sdn_controllers"), kwargs)

    def import_controllers(self, **kwargs):
        """Imports a list of discovery settings into the database

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param file: The contents of the CSV file with the list of discovery settings to be imported
             :type file: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param UnitID: The UnitID of the collector
             :type UnitID: Integer

            **Outputs**

            """

        return self.api_request(self._get_method_fullname("import_controllers"), kwargs)

    def check_credentials(self, **kwargs):
        """Performs connection to SDN/SDWAN controller, checks credentials and returns results or status id based on async_ind

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param unit_id: ID of the collector to send the request to, OC only
             :type unit_id: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param sdn_type: Type of SDN controller. Allowed values are CISCO_APIC, MERAKI, VELOCLOUD, SILVER_PEAK, VIPTELA
             :type sdn_type: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param address: Comma-separated list of controller's IP Addresses/FQDNs
             :type address: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param username: Username used to connect SDN controller
             :type username: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param password: Password used to connect SDN controller
             :type password: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param api_key: API key to access the SDN controller
             :type api_key: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` HTTP

             :param protocol: Protocol used to communicate with controller (HTTP or HTTPS)
             :type protocol: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` False

             :param use_global_proxy: Use global proxy settings to access SDN controller
             :type use_global_proxy: Boolean

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param ca_cert_content: CA certificate content to connect using HTTPS
             :type ca_cert_content: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param network_interface: Name of physical network interface which used for controller connection
             :type network_interface: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param virtual_network_id: Virtual Network ID assigned for SDN controller discovery
             :type virtual_network_id: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param proxy_address: Address of the proxy server
             :type proxy_address: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 80

             :param proxy_port: Port number the proxy listens on
             :type proxy_port: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param proxy_username: Proxy username
             :type proxy_username: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param proxy_password: Proxy password
             :type proxy_password: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` False

             :param async_ind: When false, the credential check will be run synchronously, and the API call will block until it is complete. When true, credential check id will be returned to use for subsequent calls
             :type async_ind: Boolean

            |  ``api version min:`` 3.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:``

             :param start_blackout_schedule: Blackout schedule
             :type start_blackout_schedule: String

            |  ``api version min:`` 3.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param blackout_duration: Blackout duration
             :type blackout_duration: Integer

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return text: When async_ind is false, credential check text will be returned upon completion.
             :rtype text: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return id: The internal identifier for previously initiated credential check.
             :rtype id: String

            """

        return self.api_request(self._get_method_fullname("check_credentials"), kwargs)

    def check_credentials_status(self, **kwargs):
        """Status of SDN/SDWAN controller credentials check

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param id: SDN credential check id needed to retrieve status
             :type id: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param start: The starting index(inclusive) of the returned text of the SDN credential check
             :type start: Integer

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return text: Credential check result
             :rtype text: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return start: The starting index(inclusive) of the returned text of the SDN credential check
             :rtype start: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return end: The ending index (exclusive) of the returned text of the SDN credential check
             :rtype end: Integer

            """

        return self.api_request(self._get_method_fullname("check_credentials_status"), kwargs)
